@@ -11,9 +11,9 @@
 //! [dependencies.cv-convert]
 //! version = 'x.y.z'
 //! features = [
-//!     'image_0-23',
-//!     'opencv_0-62',
-//!     'tch_0-6',
+//!     'image_0-24',
+//!     'opencv_0-63',
+//!     'tch_0-7',
 //!     'nalgebra_0-30',
 //!     'ndarray_0-15',
 //! ]
@@ -49,7 +49,7 @@
 //! let na_mat = na::DMatrix::from_vec(2, 3, vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0]);
 //! let cv_mat: cv::core::Mat = na_mat.try_into_cv().unwrap();
 //! ```
-//! //!
+//!
 //!
 //! # Supported conversions
 //!
@@ -95,8 +95,8 @@
 //!
 //! ## image -> tch
 //!
-//! - [(&)ImageBuffer](image::ImageBuffer) ->? [Tensor](tch::Tensor)
-//! - [(&)DynamicImage](image::DynamicImage) ->? [Tensor](tch::Tensor)
+//! - [(&)ImageBuffer](image::ImageBuffer) ->? [TchTensorAsImage]
+//! - [(&)DynamicImage](image::DynamicImage) ->? [TchTensorAsImage]
 //!
 //! ## image -> opencv
 //!
@@ -124,12 +124,33 @@
 //! ## opencv -> tch
 //!
 //! - [(&)Mat](opencv::core::Mat) ->? [Tensor](tch::Tensor)
-//! - [Mat](opencv::core::Mat) ->? [TensorFromMat]
+//!
+//!   The input [Mat](opencv::core::Mat) is regarded as an n-dimensional array with a m-channel elements.
+//!   The output [Tensor](tch::Tensor) have n+1 dimensions, which last additional m-sized dimension is the channel.
+//!
+//! - [(&)Mat](opencv::core::Mat) ->? [TchTensorAsImage]
+//!
+//!   The input [Mat](opencv::core::Mat) must be a 2D image.
+//!   The output [Tensor](tch::Tensor) within [TchTensorAsImage] has 3 dimensions, which last additional dimension is the channel.
+//!
+//! - [&Mat](opencv::core::Mat) ->? [OpenCvMatAsTchTensor]
 //!
 //! ## tch -> opencv
 //!
 //! - [(&)Tensor](tch::Tensor) ->? [Mat](opencv::core::Mat)
-//! - [(&)TensorAsImage](TensorAsImage) ->? [Mat](opencv::core::Mat)
+//!
+//!    The n-dimensinoal input [Tensor](tch::Tensor) is converted to a [Mat](opencv::core::Mat)
+//!    with n dimensions and a channel of size 1.
+//!
+//! - [(&)TchTensorAsImage](TchTensorAsImage) ->? [Mat](opencv::core::Mat)
+//!
+//!    The output [Mat](opencv::core::Mat) is a 2D image, which height, width and channel size
+//!    are judged from the input [TchTensorAsImage](TchTensorAsImage) shape.
+//!
+//!
+//! ## opencv -> ndarray
+//!
+//! - [&Mat](opencv::core::Mat) ->? [ArrayView](ndarray::ArrayView)
 //!
 //! # OpenCV
 //! If your system requires `opencv/clang-runtime` to build, enable the `opencv_0-62-clang-runtime` feature to solve.
@@ -152,6 +173,9 @@ use utils::*;
 pub use opencv_0_63 as opencv;
 
 // image exports
+#[cfg(feature = "image_0-24")]
+pub use image_0_24 as image;
+
 #[cfg(feature = "image_0-23")]
 pub use image_0_23 as image;
 
@@ -176,14 +200,8 @@ pub use nalgebra_0_26 as nalgebra;
 pub use ndarray_0_15 as ndarray;
 
 // tch exports
-#[cfg(feature = "tch_0-6")]
-pub use tch_0_6 as tch;
-
-#[cfg(feature = "tch_0-5")]
-pub use tch_0_5 as tch;
-
-#[cfg(feature = "tch_0-4")]
-pub use tch_0_4 as tch;
+#[cfg(feature = "tch_0-7")]
+pub use tch_0_7 as tch;
 
 // modules
 has_opencv! {
@@ -230,3 +248,10 @@ has_tch! {
         pub use with_opencv_tch::*;
     }
 }
+
+has_opencv! {
+    has_ndarray! {
+        mod with_opencv_ndarray;
+        pub use with_opencv_ndarray::*;
+    }
+}
