@@ -1,6 +1,6 @@
+use crate::tch;
 use crate::{common::*, FromCv, TryFromCv};
 use slice_of_array::prelude::*;
-use crate::tch;
 
 macro_rules! impl_from_array {
     ($elem:ty) => {
@@ -411,12 +411,55 @@ impl_from_array!(f32);
 impl_from_array!(f64);
 impl_from_array!(bool);
 
+pub use tensor_as_image::*;
+mod tensor_as_image {
+    use super::*;
+
+    /// An 2D image [Tensor](tch::Tensor) with dimension order.
+    #[derive(Debug)]
+    pub struct TchTensorAsImage
+    {
+        pub(crate) tensor: tch::Tensor,
+        pub(crate) kind: TchTensorImageShape,
+    }
+
+    /// Describes the image channel order of a [Tensor](tch::Tensor).
+    #[derive(Debug, Clone, Copy)]
+    pub enum TchTensorImageShape {
+        Whc,
+        Hwc,
+        Chw,
+        Cwh,
+    }
+
+    impl TchTensorAsImage
+    {
+        pub fn new(tensor: tch::Tensor, kind: TchTensorImageShape) -> Result<Self> {
+            let ndim = tensor.dim();
+            ensure!(
+                ndim == 3,
+                "the tensor must have 3 dimensions, but get {}",
+                ndim
+            );
+            Ok(Self { tensor, kind })
+        }
+
+        pub fn into_inner(self) -> tch::Tensor {
+            self.tensor
+        }
+
+        pub fn kind(&self) -> TchTensorImageShape {
+            self.kind
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::tch;
     use crate::TryIntoCv;
     use rand::prelude::*;
-    use crate::tch;
 
     #[test]
     fn tensor_to_array_ref() {
